import request from '@/config/axios'

// 门墩儿-企业信息 VO
export interface EnterpriseVO {
  id: number // id
  name: string // 企业全称
  anotherName: string // 企业别称
  website: string // 企业官网
  introduce: string // 公司简介
  contacts: string // 联系人
  phone: string // 联系电话
  logoUrl: string // logo图片地址
  industryId: number // 所在行业
  financingStatus: number // 融资阶段（未融资，天使轮，A轮，B轮，C轮，D轮以上，已上市，不需要融资）
  scale: number // 人员规模（0-20人，20-99人，100-499人，500-999人，1000-9999人，9999人以上）
  welfareList: string // 公司福利
  albumList: string // 公司相册
  workTime: string // 上班时间
  developHistory: string // 发展历程
  receivedHonors: string // 获得荣誉
  parentId: number // 上级id
}

// 门墩儿-企业信息 API
export const EnterpriseApi = {
  // 查询门墩儿-企业信息分页
  getEnterprisePage: async (params: any) => {
    return await request.get({ url: `/menduner/system/enterprise/page`, params })
  },

  // 查询门墩儿-企业信息详情
  getEnterprise: async (id: number) => {
    return await request.get({ url: `/menduner/system/enterprise/get?id=` + id })
  },

  // 新增门墩儿-企业信息
  createEnterprise: async (data: EnterpriseVO) => {
    return await request.post({ url: `/menduner/system/enterprise/create`, data })
  },

  // 修改门墩儿-企业信息
  updateEnterprise: async (data: EnterpriseVO) => {
    return await request.put({ url: `/menduner/system/enterprise/update`, data })
  },

  // 删除门墩儿-企业信息
  deleteEnterprise: async (id: number) => {
    return await request.delete({ url: `/menduner/system/enterprise/delete?id=` + id })
  },

  // 导出门墩儿-企业信息 Excel
  exportEnterprise: async (params) => {
    return await request.download({ url: `/menduner/system/enterprise/export-excel`, params })
  }
}